@@ -3,9 +3,7 @@ import json
 import hashlib
 
 
-class item():
-    __data = {}
-    __name = ""
+class item(object):
 
     def getName(self):
         return self.__name
@@ -22,7 +20,7 @@ class item():
 
     def insertProperty(self, name, value):
         self.__data[name] = value
-        
+
     def removeProperty(self, name):
         self.__data.pop(name)
 
@@ -69,7 +67,11 @@ class databaseDocument(object):
         if(len(self.__data) > 1):
             return 0 != self.binarySearch(self.__dictToList__(self.__data), value)
         else:
-            print("A document must be bigger than 1 item to be searchable.")
+            for x in self.__data:
+                if self.__data[x] == value:
+                    return True
+                else:
+                    return False
 
     def __init__(self, data, name):
         self.__data = data
@@ -101,7 +103,7 @@ class databaseDocument(object):
         try:
             return self.__data[name]
         except:
-            return item({"Err": True}, "Err")
+            return False
 
     def getHash(self) -> hashlib.md5:
         return hashlib.md5((str(json.dumps(self.get(), default=databasecontroller.serialize))).encode('utf-8')).hexdigest()
